{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "concat"
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.merged_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#merge.cwl/merged_vcf_basename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "id": "#merge.cwl/merged_vcf"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "--splitMultiallelics",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_2/min_var_freq"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#workflow.cwl_2/sample_name"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram",
                            "id": "#workflow.cwl_2/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl_2/cram_to_bam"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_filter/filtered_vcf",
                            "id": "#workflow.cwl_2/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_2/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram_to_bam/bam",
                            "id": "#workflow.cwl_2/fp_filter/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/min_var_freq",
                            "id": "#workflow.cwl_2/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#workflow.cwl_2/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/fp_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/sample_name",
                            "id": "#workflow.cwl_2/fp_filter/sample_name"
                        },
                        {
                            "source": "#workflow.cwl_2/normalize_variants/normalized_vcf",
                            "id": "#workflow.cwl_2/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_bgzip/bgzipped_file",
                            "id": "#workflow.cwl_2/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#workflow.cwl_2/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#workflow.cwl_2/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/hard_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/fp_index/indexed_vcf",
                            "id": "#workflow.cwl_2/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/hard_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/hard_filter"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/normalize_variants/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/vcf",
                            "id": "#workflow.cwl_2/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/normalize_variants/normalized_vcf"
                    ],
                    "id": "#workflow.cwl_2/normalize_variants"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_gt.cwl"
        },
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#process_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#process_vcf.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#process_vcf.cwl/processed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_gt.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/vcf",
                            "id": "#process_vcf.cwl/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/add_gt/processed_vcf"
                    ],
                    "id": "#process_vcf.cwl/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/add_gt/processed_vcf",
                            "id": "#process_vcf.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#process_vcf.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/bgzip/bgzipped_file",
                            "id": "#process_vcf.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/index/indexed_vcf"
                    ],
                    "id": "#process_vcf.cwl/index"
                }
            ],
            "id": "#process_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "strelka 2.7.1",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/strelka_helper.pl"
            ],
            "requirements": [
                {
                    "coresMin": 4,
                    "ramMin": 4000,
                    "class": "ResourceRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.cpu_reserved)",
                    "position": 1
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": 2
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#strelka.cwl/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--exome",
                        "position": 6
                    },
                    "id": "#strelka.cwl/exome_mode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--normalBam=",
                        "separate": false,
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#strelka.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--referenceFasta=",
                        "separate": false,
                        "position": 5
                    },
                    "id": "#strelka.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--tumorBam=",
                        "separate": false,
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#strelka.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.indels.vcf.gz"
                    },
                    "id": "#strelka.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.snvs.vcf.gz"
                    },
                    "id": "#strelka.cwl/snvs"
                }
            ],
            "id": "#strelka.cwl"
        },
        {
            "class": "Workflow",
            "label": "strelka workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/cpu_reserved"
                },
                {
                    "type": "boolean",
                    "id": "#main/exome_mode"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#main/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#main/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/filter/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter/reference"
                        },
                        {
                            "valueFrom": "strelka",
                            "id": "#main/filter/variant_caller"
                        },
                        {
                            "source": "#main/region_filter/filtered_vcf",
                            "id": "#main/filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter/unfiltered_vcf",
                        "#main/filter/filtered_vcf"
                    ],
                    "id": "#main/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_vcf",
                            "id": "#main/index_full/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_full/indexed_vcf"
                    ],
                    "id": "#main/index_full"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#main/process/processed_vcf",
                            "id": "#main/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_vcf"
                    ],
                    "id": "#main/merge"
                },
                {
                    "scatter": "#main/process/vcf",
                    "run": "#process_vcf.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/strelka/snvs",
                                "#main/strelka/indels"
                            ],
                            "id": "#main/process/vcf"
                        }
                    ],
                    "out": [
                        "#main/process/processed_vcf"
                    ],
                    "id": "#main/process"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/region_filter/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/region_filter/reference"
                        },
                        {
                            "source": "#main/index_full/indexed_vcf",
                            "id": "#main/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/region_filter/filtered_vcf"
                    ],
                    "id": "#main/region_filter"
                },
                {
                    "run": "#strelka.cwl",
                    "in": [
                        {
                            "source": "#main/cpu_reserved",
                            "id": "#main/strelka/cpu_reserved"
                        },
                        {
                            "source": "#main/exome_mode",
                            "id": "#main/strelka/exome_mode"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/strelka/normal_cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/strelka/reference"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/strelka/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/strelka/indels",
                        "#main/strelka/snvs"
                    ],
                    "id": "#main/strelka"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
